@@ -115,12 +115,12 @@ void KServicePrivate::init(const KDesktopFile *config, KService *q)
     m_untranslatedGenericName = desktopGroup.readEntryUntranslated("GenericName");
     m_untranslatedName = desktopGroup.readEntryUntranslated("Name");
 
-    m_lstFormFactors = entryMap.take(QStringLiteral("X-KDE-FormFactors")).split(QLatin1Char(' '), Qt::SkipEmptyParts);
+    m_lstFormFactors = entryMap.take(QStringLiteral("X-KDE-FormFactors")).split(QLatin1Char(','), Qt::SkipEmptyParts);
 
     if (entryMap.remove(QStringLiteral("Keywords"))) {
         m_lstKeywords = desktopGroup.readXdgListEntry("Keywords");
     }
-    m_lstKeywords += entryMap.take(QStringLiteral("X-KDE-Keywords")).split(QLatin1Char(' '), Qt::SkipEmptyParts);
+
     if (entryMap.remove(QStringLiteral("Categories"))) {
         categories = desktopGroup.readXdgListEntry("Categories");
     }
@@ -759,12 +759,7 @@ QStringList KService::schemeHandlers() const
 
 QStringList KService::supportedProtocols() const
 {
-    Q_D(const KService);
-
-    QStringList ret;
-
-    ret << schemeHandlers();
-
+    QStringList ret = schemeHandlers();
     const QStringList protocols = property<QStringList>(QStringLiteral("X-KDE-Protocols"));
     for (const QString &protocol : protocols) {
         if (!ret.contains(protocol)) {
